@@ -78,7 +78,7 @@ class ClusteringOptimizer:
 			processor = Parallel(n_jobs=n_external_jobs, backend='threading', require='sharedmem')
 			result = processor(
 				delayed(get_scores)(k=k, n_jobs=n_internal_jobs)
-				for k in iterate(iterable=range(self._max_k, self._min_k - 1, -1), echo_items=True)
+				for k in iterate(iterable=range(self._max_k, self._min_k - 1, -1), echo_items=True, echo=echo)
 			)
 
 			for k, model, inertia, distortion, silhouette_score in result:
